==> mediawiki-1.36.1-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/Scribunto/Scribunto.namespaces.php <==
<?php
/**
 * Internationalisation file for extension Scribunto.
 *
 * @file
 * @ingroup Extensions
 */

$namespaceNames = [];

$namespaceNames['en'] = [
	828 => 'Module',
	829 => 'Module_talk',
];

$namespaceNames['ab'] = [
	828 => 'Амодул',
	829 => 'Амодул_ахцәажәара',
];

$namespaceNames['alt'] = [
	828 => 'Модуль',
	829 => 'Модульды_шӱӱжери',
];

$namespaceNames['an'] = [
	828 => 'Módulo',
	829 => 'Descusión_módulo',
];

$namespaceNames['ar'] = [
	828 => 'وحدة',
	829 => 'نقاش_الوحدة',
];

$namespaceNames['ast'] = [
	828 => 'Módulu',
	829 => 'Módulu_alderique',
];

$namespaceNames['atj'] = [
	828 => 'Aitapihikewin',
	829 => 'Aitapihikan_ke_ici_aimihitonaniwok',
];

$namespaceNames['avk'] = [
	828 => 'Siba',
	829 => 'Sibaprilara',
];

$namespaceNames['azb'] = [
	828 => 'ماژول',
	829 => 'ماژول_دانیشیغی',
];

$namespaceNames['ba'] = [
	828 => 'Модуль',
	829 => 'Модуль_буйынса_фекерләшеү',
];

$namespaceNames['ban'] = [
	828 => 'Modul',
	829 => 'Pabligbagan_Modul',
];

$namespaceNames['be'] = [
	828 => 'Модуль',
	829 => 'Размовы_пра_модуль',
];

$namespaceNames['be-tarask'] = [
	828 => 'Модуль',
	829 => 'Абмеркаваньне_модулю',
];

$namespaceNames['bg'] = [
	828 => 'Модул',
	829 => 'Модул_беседа',
];

$namespaceNames['bgn'] = [
	828 => 'ماژول',
	829 => 'ماژول_ئی_گپ',
];

$namespaceNames['bn'] = [
	828 => 'মডিউল',
	829 => 'মডিউল_আলাপ',
];

$namespaceNames['br'] = [
	828 => 'Modulenn',
	829 => 'Kaozeadenn_modulenn',
];

$namespaceNames['bs'] = [
	828 => 'Modul',
	829 => 'Razgovor_o_modulu',
];

$namespaceNames['ca'] = [
	828 => 'Mòdul',
	829 => 'Mòdul_Discussió',
];

$namespaceNames['ce'] = [
	828 => 'Модуль',
	829 => 'Модулин_дийцаре',
];

$namespaceNames['ckb'] = [
	828 => 'مۆدیوول',
	829 => 'لێدوانی_مۆدیوول',
];

$namespaceNames['crh'] = [
	828 => 'Modul',
	829 => 'Modul_muzakeresi',
];

$namespaceNames['cs'] = [
	828 => 'Modul',
	829 => 'Diskuse_k_modulu',
];

$namespaceNames['cy'] = [
	828 => 'Modiwl',
	829 => 'Sgwrs_modiwl',
];

$namespaceNames['da'] = [
	828 => 'Modul',
	829 => 'Moduldiskussion',
];

$namespaceNames['de'] = [
	828 => 'Modul',
	829 => 'Modul_Diskussion',
];

$namespaceNames['din'] = [
	828 => 'Mukääcëtök',
	829 => 'Jam_wɛ̈t_ë_mukääcëtök',
];

$namespaceNames['diq'] = [
	828 => 'Modul',
	829 => 'Modul_vaten',
];

$namespaceNames['dsb'] = [
	828 => 'Modul',
	829 => 'Modul_diskusija',
];

$namespaceNames['dty'] = [
	828 => 'मोड्युल',
	829 => 'मोड्युल_कुरणि',
];

$namespaceNames['dv'] = [
	828 => 'މޮޑިއުލް',
	829 => 'މޮޑިއުލް_ޚިޔާލު',
];

$namespaceNames['eml'] = [
	828 => 'Mòdul',
	829 => 'Discusiòun_dal_Mòdul',
];

$namespaceNames['eo'] = [
	828 => 'Modulo',
	829 => 'Modulo-Diskuto',
];

$namespaceNames['es'] = [
	828 => 'Módulo',
	829 => 'Módulo_discusión',
];

$namespaceNames['et'] = [
	828 => 'Moodul',
	829 => 'Mooduli_arutelu',
];

$namespaceNames['eu'] = [
	828 => 'Modulu',
	829 => 'Modulu_eztabaida',
];

$namespaceNames['fa'] = [
	828 => 'پودمان',
	829 => 'بحث_پودمان',
];

$namespaceNames['fi'] = [
	828 => 'Moduuli',
	829 => 'Keskustelu_moduulista',
];

$namespaceNames['fr'] = [
	828 => 'Module',
	829 => 'Discussion_module',
];

$namespaceNames['gcr'] = [
	828 => 'Modjoul',
	829 => 'Diskisyon_modjoul',
];

$namespaceNames['gd'] = [
	828 => 'Mòideal',
	829 => 'Deasbaireachd_mòideil',
];

$namespaceNames['gl'] = [
	828 => 'Módulo',
	829 => 'Conversa_módulo',
];

$namespaceNames['gom-deva'] = [
	828 => 'एकक',
	829 => 'एकक_चर्चा',
];

$namespaceNames['gu'] = [
	828 => 'વિભાગ',
	829 => 'વિભાગ_ચર્ચા',
];

$namespaceNames['he'] = [
	828 => 'יחידה',
	829 => 'שיחת_יחידה',
];

$namespaceNames['hr'] = [
	828 => 'Modul',
	829 => 'Razgovor_o_modulu',
];

$namespaceNames['hsb'] = [
	828 => 'Modul',
	829 => 'Modul_diskusija',
];

$namespaceNames['hu'] = [
	828 => 'Modul',
	829 => 'Modulvita',
];

$namespaceNames['hy'] = [
	828 => 'Մոդուլ',
	829 => 'Մոդուլի_քննարկում',
];

$namespaceNames['inh'] = [
	828 => 'Модуль',
	829 => 'Модуль_ювцар',
];

$namespaceNames['id'] = [
	828 => 'Modul',
	829 => 'Pembicaraan_Modul',
];

$namespaceNames['ilo'] = [
	828 => 'Modulo',
	829 => 'Modulo_tungtungan',
];

$namespaceNames['it'] = [
	828 => 'Modulo',
	829 => 'Discussioni_modulo',
];

$namespaceNames['ja'] = [
	828 => 'モジュール',
	829 => 'モジュール・トーク',
];

$namespaceNames['jv'] = [
	828 => 'Modhul',
	829 => 'Parembugan_Modhul',
];

$namespaceNames['ka'] = [
	828 => 'მოდული',
	829 => 'მოდულის_განხილვა',
];

$namespaceNames['kn'] = [
	828 => 'ಮಾಡ್ಯೂಲ್',
	829 => 'ಮಾಡ್ಯೂಲ್_ಚರ್ಚೆ',
];

$namespaceNames['ko'] = [
	828 => '모듈',
	829 => '모듈토론',
];

$namespaceNames['ku'] = [
	828 => 'Modul',
	829 => 'Gotûbêja_modulê',
];

$namespaceNames['lb'] = [
	828 => 'Modul',
	829 => 'Modul_Diskussioun',
];

$namespaceNames['lfn'] = [
	828 => 'Modulo',
	829 => 'Modulo_Discute',
];

$namespaceNames['lmo'] = [
	828 => 'Mòdul',
	829 => 'Ciciarada_Mòdul',
];

$namespaceNames['lrc'] = [
	828 => 'ماجول',
	829 => 'چک_چنه_ماجول',
];

$namespaceNames['lv'] = [
	828 => 'Modulis',
	829 => 'Moduļa_diskusija',
];

$namespaceNames['mai'] = [
	828 => 'मोड्युल',
	829 => 'मोड्युल_वार्ता',
];

$namespaceNames['min'] = [
	828 => 'Modul',
	829 => 'Rundiang_Modul',
];

$namespaceNames['mk'] = [
	828 => 'Модул',
	829 => 'Разговор_за_модул',
];

$namespaceNames['ml'] = [
	828 => 'ഘടകം',
	829 => 'ഘടകത്തിന്റെ_സംവാദം',
];

$namespaceNames['mnw'] = [
	828 => 'မဝ်ဂျူ',
	829 => 'မဝ်ဂျူ_ဓရီုကျာ',
];

$namespaceNames['mr'] = [
	828 => 'विभाग',
	829 => 'विभाग_चर्चा',
];

$namespaceNames['ms'] = [
	828 => 'Modul',
];

$namespaceNames['mwl'] = [
	828 => 'Módulo',
	829 => 'Cumbersa_módulo',
];

$namespaceNames['my'] = [
	828 => 'မော်ဂျူး',
	829 => 'မော်ဂျူး_ဆွေးနွေးချက်',
];

$namespaceNames['mzn'] = [
	828 => 'ماژول',
	829 => 'ماژول_گپ',
];

$namespaceNames['nap'] = [
	828 => 'Modulo',
	829 => 'Modulo_chiàcchiera',
];

$namespaceNames['nb'] = [
	828 => 'Modul',
	829 => 'Moduldiskusjon',
];

$namespaceNames['ne'] = [
	828 => 'मोड्युल',
	829 => 'मोड्युल_वार्तालाप',
];

$namespaceNames['nl'] = [
	828 => 'Module',
	829 => 'Overleg_module',
];

$namespaceNames['nn'] = [
	828 => 'Modul',
	829 => 'Moduldiskusjon',
];

$namespaceNames['nqo'] = [
	828 => 'ߗߋ߬ߞߙߊߞߏ',
	829 => 'ߗߋ߬ߞߙߊߞߏ ߢߊߝߐߞߣߍ',
];

$namespaceNames['or'] = [
	828 => 'ମଡ୍ୟୁଲ',
	829 => 'ମଡ୍ୟୁଲ_ଆଲୋଚନା',
];

$namespaceNames['pa'] = [
	828 => 'ਮੌਡਿਊਲ',
	829 => 'ਮੌਡਿਊਲ_ਗੱਲ-ਬਾਤ',
];

$namespaceNames['pl'] = [
	828 => 'Moduł',
	829 => 'Dyskusja_modułu',
];

$namespaceNames['pnb'] = [
	828 => 'ماڈیول',
	829 => 'ماڈیول_گل_بات',
];

$namespaceNames['pt'] = [
	828 => 'Módulo',
	829 => 'Módulo_Discussão',
];

$namespaceNames['pt-br'] = [
	828 => 'Módulo',
	829 => 'Módulo_Discussão',
];

$namespaceNames['ro'] = [
	828 => 'Modul',
	829 => 'Discuție_Modul',
];

$namespaceNames['ru'] = [
	828 => 'Модуль',
	829 => 'Обсуждение_модуля',
];

$namespaceNames['sa'] = [
	828 => 'पटलम्',
	829 => 'पटलसम्भाषणम्',
];

$namespaceNames['sat'] = [
	828 => 'ᱢᱳᱰᱩᱞ',
	829 => 'ᱢᱳᱰᱩᱞ_ᱜᱟᱞᱢᱟᱨᱟᱣ',
];

$namespaceNames['sd'] = [
	828 => 'ماڊيول',
	829 => 'ماڊيول_بحث',
];

$namespaceNames['se'] = [
	828 => 'Modula',
	829 => 'Modulaságastallan',
];

$namespaceNames['sh'] = [
	828 => 'Modul',
	829 => 'Razgovor_o_modulu',
];

$namespaceNames['shn'] = [
	828 => 'မေႃႇၵျူး',
	829 => 'ဢုပ်ႇၵုမ်_မေႃႇၵျူး',
];

$namespaceNames['shy-latn'] = [
	828 => 'Amṣada',
	829 => 'Amṣada_tameslayt',
];

$namespaceNames['sk'] = [
	828 => 'Modul',
	829 => 'Diskusia_k_modulu',
];

$namespaceNames['skr-arab'] = [
	828 => 'ماڈیول',
	829 => 'ماڈیول_ڳالھ_مہاڑ',
];

$namespaceNames['sl'] = [
	828 => 'Modul',
	829 => 'Pogovor_o_modulu',
];

$namespaceNames['smn'] = [
	828 => 'Mooduul',
	829 => 'Savâstâllâm_modulist',
];

$namespaceNames['sq'] = [
	828 => 'Moduli',
	829 => 'Moduli_diskutim',
];

$namespaceNames['sr'] = [
	828 => 'Модул',
	829 => 'Разговор о модулу',
];

$namespaceNames['sr-ec'] = [
	828 => 'Модул',
	829 => 'Разговор_о_модулу',
];

$namespaceNames['sr-el'] = [
	828 => 'Modul',
	829 => 'Razgovor_o_modulu',
];

$namespaceNames['sv'] = [
	828 => 'Modul',
	829 => 'Moduldiskussion',
];

$namespaceNames['szy'] = [
	828 => 'bacu-saupu',
	829 => 'pisubelidan_tu_kamu_i_bacu-saupu_sapimatatengil',
];

$namespaceNames['tcy'] = [
	828 => 'ಮೋಡ್ಯೂಲ್',
	829 => 'ಮೋಡ್ಯೂಲ್_ಪಾತೆರ',
];

$namespaceNames['te'] = [
	828 => 'మాడ్యూల్',
	829 => 'మాడ్యూల్ చర్చ',
];

$namespaceNames['ti'] = [
	828 => 'ሞድዩል',
	829 => 'ሞድዩል_ምይይጥ',
];

$namespaceNames['tg'] = [
	828 => 'Модул',
	829 => 'Баҳси_Модул',
];

$namespaceNames['th'] = [
	828 => 'มอดูล',
	829 => 'คุยเรื่องมอดูล',
];

$namespaceNames['tr'] = [
	828 => 'Modül',
	829 => 'Modül_tartışma',
];

$namespaceNames['uk'] = [
	828 => 'Модуль',
	829 => 'Обговорення_модуля',
];

$namespaceNames['ur'] = [
	828 => 'ماڈیول',
	829 => 'تبادلۂ_خیال_ماڈیول',
];

$namespaceNames['vi'] = [
	828 => 'Mô_đun',
	829 => 'Thảo_luận_Mô_đun',
];

$namespaceNames['yue'] = [
	828 => '模組',
	829 => '模組討論',
];

$namespaceNames['zh'] = [
	828 => '模块',
	829 => '模块讨论',
];

$namespaceNames['zh-hans'] = [
	828 => '模块',
	829 => '模块讨论',
];

$namespaceNames['zh-hant'] = [
	828 => '模組',
	829 => '模組討論',
];

==> mediawiki-1.37.0-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/Scribunto/Scribunto.namespaces.php <==
<?php
/**
 * Internationalisation file for extension Scribunto.
 *
 * @file
 * @ingroup Extensions
 */

$namespaceNames = [];

$namespaceNames['en'] = [
	828 => 'Module',
	829 => 'Module_talk',
];

$namespaceNames['ab'] = [
	828 => 'Амодул',
	829 => 'Амодул_ахцәажәара',
];

$namespaceNames['alt'] = [
	828 => 'Модуль',
	829 => 'Модульды_шӱӱжери',
];

$namespaceNames['an'] = [
	828 => 'Módulo',
	829 => 'Descusión_módulo',
];

$namespaceNames['ar'] = [
	828 => 'وحدة',
	829 => 'نقاش_الوحدة',
];

$namespaceNames['ast'] = [
	828 => 'Módulu',
	829 => 'Módulu_alderique',
];

$namespaceNames['atj'] = [
	828 => 'Aitapihikewin',
	829 => 'Aitapihikan_ke_ici_aimihitonaniwok',
];

$namespaceNames['avk'] = [
	828 => 'Siba',
	829 => 'Sibaprilara',
];

$namespaceNames['az'] = [
	828 => 'Modul',
	829 => 'Modul_müzakirəsi',
];

$namespaceNames['azb'] = [
	828 => 'ماژول',
	829 => 'ماژول_دانیشیغی',
];

$namespaceNames['ba'] = [
	828 => 'Модуль',
	829 => 'Модуль_буйынса_фекерләшеү',
];

$namespaceNames['ban'] = [
	828 => 'Modul',
	829 => 'Pabligbagan_Modul',
];

$namespaceNames['be'] = [
	828 => 'Модуль',
	829 => 'Размовы_пра_модуль',
];

$namespaceNames['be-tarask'] = [
	828 => 'Модуль',
	829 => 'Абмеркаваньне_модулю',
];

$namespaceNames['bg'] = [
	828 => 'Модул',
	829 => 'Модул_беседа',
];

$namespaceNames['bgn'] = [
	828 => 'ماژول',
	829 => 'ماژول_ئی_گپ',
];

$namespaceNames['bn'] = [
	828 => 'মডিউল',
	829 => 'মডিউল_আলাপ',
];

$namespaceNames['br'] = [
	828 => 'Modulenn',
	829 => 'Kaozeadenn_modulenn',
];

$namespaceNames['bs'] = [
	828 => 'Modul',
	829 => 'Razgovor_o_modulu',
];

$namespaceNames['ca'] = [
	828 => 'Mòdul',
	829 => 'Mòdul_Discussió',
];

$namespaceNames['ce'] = [
	828 => 'Модуль',
	829 => 'Модулин_дийцаре',
];

$namespaceNames['ckb'] = [
	828 => 'مۆدیوول',
	829 => 'لێدوانی_مۆدیوول',
];

$namespaceNames['crh'] = [
	828 => 'Modul',
	829 => 'Modul_muzakeresi',
];

$namespaceNames['cs'] = [
	828 => 'Modul',
	829 => 'Diskuse_k_modulu',
];

$namespaceNames['cy'] = [
	828 => 'Modiwl',
	829 => 'Sgwrs_modiwl',
];

$namespaceNames['da'] = [
	828 => 'Modul',
	829 => 'Moduldiskussion',
];

$namespaceNames['de'] = [
	828 => 'Modul',
	829 => 'Modul_Diskussion',
];

$namespaceNames['din'] = [
	828 => 'Mukääcëtök',
	829 => 'Jam_wɛ̈t_ë_mukääcëtök',
];

$namespaceNames['diq'] = [
	828 => 'Modul',
	829 => 'Modul_vaten',
];

$namespaceNames['dsb'] = [
	828 => 'Modul',
	829 => 'Modul_diskusija',
];

$namespaceNames['dty'] = [
	828 => 'मोड्युल',
	829 => 'मोड्युल_कुरणि',
];

$namespaceNames['dv'] = [
	828 => 'މޮޑިއުލް',
	829 => 'މޮޑިއުލް_ޚިޔާލު',
];

$namespaceNames['eml'] = [
	828 => 'Mòdul',
	829 => 'Discusiòun_dal_Mòdul',
];

$namespaceNames['eo'] = [
	828 => 'Modulo',
	829 => 'Modulo-Diskuto',
];

$namespaceNames['es'] = [
	828 => 'Módulo',
	829 => 'Módulo_discusión',
];

$namespaceNames['et'] = [
	828 => 'Moodul',
	829 => 'Mooduli_arutelu',
];

$namespaceNames['eu'] = [
	828 => 'Modulu',
	829 => 'Modulu_eztabaida',
];

$namespaceNames['fa'] = [
	828 => 'پودمان',
	829 => 'بحث_پودمان',
];

$namespaceNames['fi'] = [
	828 => 'Moduuli',
	829 => 'Keskustelu_moduulista',
];

$namespaceNames['fr'] = [
	828 => 'Module',
	829 => 'Discussion_module',
];

$namespaceNames['gcr'] = [
	828 => 'Modjoul',
	829 => 'Diskisyon_modjoul',
];

$namespaceNames['gd'] = [
	828 => 'Mòideal',
	829 => 'Deasbaireachd_mòideil',
];

$namespaceNames['gl'] = [
	828 => 'Módulo',
	829 => 'Conversa_módulo',
];

$namespaceNames['gom-deva'] = [
	828 => 'एकक',
	829 => 'एकक_चर्चा',
];

$namespaceNames['gu'] = [
	828 => 'વિભાગ',
	829 => 'વિભાગ_ચર્ચા',
];

$namespaceNames['he'] = [
	828 => 'יחידה',
	829 => 'שיחת_יחידה',
];

$namespaceNames['hr'] = [
	828 => 'Modul',
	829 => 'Razgovor_o_modulu',
];

$namespaceNames['hsb'] = [
	828 => 'Modul',
	829 => 'Modul_diskusija',
];

$namespaceNames['hu'] = [
	828 => 'Modul',
	829 => 'Modulvita',
];

$namespaceNames['hy'] = [
	828 => 'Մոդուլ',
	829 => 'Մոդուլի_քննարկում',
];

$namespaceNames['inh'] = [
	828 => 'Модуль',
	829 => 'Модуль_ювцар',
];

$namespaceNames['id'] = [
	828 => 'Modul',
	829 => 'Pembicaraan_Modul',
];

$namespaceNames['ilo'] = [
	828 => 'Modulo',
	829 => 'Modulo_tungtungan',
];

$namespaceNames['it'] = [
	828 => 'Modulo',
	829 => 'Discussioni_modulo',
];

$namespaceNames['ja'] = [
	828 => 'モジュール',
	829 => 'モジュール・トーク',
];

$namespaceNames['jv'] = [
	828 => 'Modhul',
	829 => 'Parembugan_Modhul',
];

$namespaceNames['ka'] = [
	828 => 'მოდული',
	829 => 'მოდულის_განხილვა',
];

$namespaceNames['kn'] = [
	828 => 'ಮಾಡ್ಯೂಲ್',
	829 => 'ಮಾಡ್ಯೂಲ್_ಚರ್ಚೆ',
];

$namespaceNames['ko'] = [
	828 => '모듈',
	829 => '모듈토론',
];

$namespaceNames['ku'] = [
	828 => 'Modul',
	829 => 'Gotûbêja_modulê',
];

$namespaceNames['lb'] = [
	828 => 'Modul',
	829 => 'Modul_Diskussioun',
];

$namespaceNames['lfn'] = [
	828 => 'Modulo',
	829 => 'Modulo_Discute',
];

$namespaceNames['lmo'] = [
	828 => 'Mòdul',
	829 => 'Ciciarada_Mòdul',
];

$namespaceNames['lrc'] = [
	828 => 'ماجول',
	829 => 'چک_چنه_ماجول',
];

$namespaceNames['lv'] = [
	828 => 'Modulis',
	829 => 'Moduļa_diskusija',
];

$namespaceNames['mai'] = [
	828 => 'मोड्युल',
	829 => 'मोड्युल_वार्ता',
];

$namespaceNames['min'] = [
	828 => 'Modul',
	829 => 'Rundiang_Modul',
];

$namespaceNames['mk'] = [
	828 => 'Модул',
	829 => 'Разговор_за_модул',
];

$namespaceNames['ml'] = [
	828 => 'ഘടകം',
	829 => 'ഘടകത്തിന്റെ_സംവാദം',
];

$namespaceNames['mnw'] = [
	828 => 'မဝ်ဂျူ',
	829 => 'မဝ်ဂျူ_ဓရီုကျာ',
];

$namespaceNames['mr'] = [
	828 => 'विभाग',
	829 => 'विभाग_चर्चा',
];

$namespaceNames['ms'] = [
	828 => 'Modul',
	829 => 'Perbincangan_modul',
];

$namespaceNames['ms-arab'] = [
	828 => 'مودول',
	829 => 'ڤربينچڠن_مودول',
];

$namespaceNames['mwl'] = [
	828 => 'Módulo',
	829 => 'Cumbersa_módulo',
];

$namespaceNames['my'] = [
	828 => 'မော်ဂျူး',
	829 => 'မော်ဂျူး_ဆွေးနွေးချက်',
];

$namespaceNames['mzn'] = [
	828 => 'ماژول',
	829 => 'ماژول_گپ',
];

$namespaceNames['nap'] = [
	828 => 'Modulo',
	829 => 'Modulo_chiàcchiera',
];

$namespaceNames['nb'] = [
	828 => 'Modul',
	829 => 'Moduldiskusjon',
];

$namespaceNames['ne'] = [
	828 => 'मोड्युल',
	829 => 'मोड्युल_वार्तालाप',
];

$namespaceNames['nl'] = [
	828 => 'Module',
	829 => 'Overleg_module',
];

$namespaceNames['nn'] = [
	828 => 'Modul',
	829 => 'Moduldiskusjon',
];

$namespaceNames['nqo'] = [
	828 => 'ߗߋ߬ߞߙߊߞߏ',
	829 => 'ߗߋ߬ߞߙߊߞߏ ߢߊߝߐߞߣߍ',
];

$namespaceNames['or'] = [
	828 => 'ମଡ୍ୟୁଲ',
	829 => 'ମଡ୍ୟୁଲ_ଆଲୋଚନା',
];

$namespaceNames['pa'] = [
	828 => 'ਮੌਡਿਊਲ',
	829 => 'ਮੌਡਿਊਲ_ਗੱਲ-ਬਾਤ',
];

$namespaceNames['pl'] = [
	828 => 'Moduł',
	829 => 'Dyskusja_modułu',
];

$namespaceNames['pnb'] = [
	828 => 'ماڈیول',
	829 => 'ماڈیول_گل_بات',
];

$namespaceNames['pt'] = [
	828 => 'Módulo',
	829 => 'Módulo_Discussão',
];

$namespaceNames['pt-br'] = [
	828 => 'Módulo',
	829 => 'Módulo_Discussão',
];

$namespaceNames['ro'] = [
	828 => 'Modul',
	829 => 'Discuție_Modul',
];

$namespaceNames['ru'] = [
	828 => 'Модуль',
	829 => 'Обсуждение_модуля',
];

$namespaceNames['sa'] = [
	828 => 'पटलम्',
	829 => 'पटलसम्भाषणम्',
];

$namespaceNames['sat'] = [
	828 => 'ᱢᱳᱰᱩᱞ',
	829 => 'ᱢᱳᱰᱩᱞ_ᱜᱟᱞᱢᱟᱨᱟᱣ',
];

$namespaceNames['sd'] = [
	828 => 'ماڊيول',
	829 => 'ماڊيول_بحث',
];

$namespaceNames['se'] = [
	828 => 'Modula',
	829 => 'Modulaságastallan',
];

$namespaceNames['sh'] = [
	828 => 'Modul',
	829 => 'Razgovor_o_modulu',
];

$namespaceNames['shn'] = [
	828 => 'မေႃႇၵျူး',
	829 => 'ဢုပ်ႇၵုမ်_မေႃႇၵျူး',
];

$namespaceNames['shy-latn'] = [
	828 => 'Amṣada',
	829 => 'Amṣada_tameslayt',
];

$namespaceNames['sk'] = [
	828 => 'Modul',
	829 => 'Diskusia_k_modulu',
];

$namespaceNames['skr-arab'] = [
	828 => 'ماڈیول',
	829 => 'ماڈیول_ڳالھ_مہاڑ',
];

$namespaceNames['sl'] = [
	828 => 'Modul',
	829 => 'Pogovor_o_modulu',
];

$namespaceNames['smn'] = [
	828 => 'Mooduul',
	829 => 'Savâstâllâm_modulist',
];

$namespaceNames['sq'] = [
	828 => 'Moduli',
	829 => 'Moduli_diskutim',
];

$namespaceNames['sr'] = [
	828 => 'Модул',
	829 => 'Разговор о модулу',
];

$namespaceNames['sr-ec'] = [
	828 => 'Модул',
	829 => 'Разговор_о_модулу',
];

$namespaceNames['sr-el'] = [
	828 => 'Modul',
	829 => 'Razgovor_o_modulu',
];

$namespaceNames['sv'] = [
	828 => 'Modul',
	829 => 'Moduldiskussion',
];

$namespaceNames['szy'] = [
	828 => 'bacu-saupu',
	829 => 'pisubelidan_tu_kamu_i_bacu-saupu_sapimatatengil',
];

$namespaceNames['tcy'] = [
	828 => 'ಮೋಡ್ಯೂಲ್',
	829 => 'ಮೋಡ್ಯೂಲ್_ಪಾತೆರ',
];

$namespaceNames['te'] = [
	828 => 'మాడ్యూల్',
	829 => 'మాడ్యూల్ చర్చ',
];

$namespaceNames['ti'] = [
	828 => 'ሞድዩል',
	829 => 'ምይይጥ_ሞድዩል',
];

$namespaceNames['tg'] = [
	828 => 'Модул',
	829 => 'Баҳси_Модул',
];

$namespaceNames['th'] = [
	828 => 'มอดูล',
	829 => 'คุยเรื่องมอดูล',
];

$namespaceNames['tr'] = [
	828 => 'Modül',
	829 => 'Modül_tartışma',
];

$namespaceNames['uk'] = [
	828 => 'Модуль',
	829 => 'Обговорення_модуля',
];

$namespaceNames['ur'] = [
	828 => 'ماڈیول',
	829 => 'تبادلۂ_خیال_ماڈیول',
];

$namespaceNames['vi'] = [
	828 => 'Mô_đun',
	829 => 'Thảo_luận_Mô_đun',
];

$namespaceNames['yue'] = [
	828 => '模組',
	829 => '模組討論',
];

$namespaceNames['zh'] = [
	828 => '模块',
	829 => '模块讨论',
];

$namespaceNames['zh-hans'] = [
	828 => '模块',
	829 => '模块讨论',
];

$namespaceNames['zh-hant'] = [
	828 => '模組',
	829 => '模組討論',
];
